@import url('https://fonts.googleapis.com/css?family=Roboto');

td, tr {
    padding-right: 1px;
    padding-left: 1px;
}

.tight {
    padding: 3px 3px;
}

.tighter {
    padding: 1px 1px;
}

.text-small {
    font-size: .75em;
}

.text-normal {
    font-size: 1em;
}

.text-right {
    text-align: right;
}

.text-center {
    text-align: center;
}

.info {
    color: red;
}

.part-list {

}

.td-small {
    max-width: 80px;
    min-width: 80px;
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis;
}

.td-med {
    max-width: 140px;
    min-width: 140px;
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis;
}

.td-large {
    max-width: 450px;
    min-width: 450px;
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis;
}
